"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const NodeSelector_1 = require("./NodeSelector");
const PlusIcon_1 = require("./icons/PlusIcon");
const MinusIcon_1 = require("./icons/MinusIcon");
const helper_1 = require("./helper");
const ContextWrapped_1 = require("./ContextWrapped");
;
class ArrayNode extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            collapsed: props.depth > props.minLevel,
            handleExpand: this.handleExpand.bind(this),
            userOverrideCollapse: false,
            itemCount: props.items.length
        };
    }
    static getDerivedStateFromProps(nextProps, prevState) {
        if (nextProps.expandedItems.includes(helper_1.pathBuild(nextProps.dataPath)) && prevState.userOverrideCollapse === false) {
            return { collapsed: false };
        }
        return null;
    }
    handleExpand() {
        this.setState({ collapsed: !this.state.collapsed, userOverrideCollapse: true });
    }
    render() {
        const { depth, highlightedItems } = this.props;
        const newDepth = depth + 1;
        let content;
        if (!this.state.collapsed) {
            content = this.props.items.map((el, index) => {
                const dataPath = [...this.props.dataPath];
                dataPath.push(`[${index}]`);
                const attrib = helper_1.pathBuild(dataPath);
                const highlighted = highlightedItems.find(el => el.path === attrib);
                const newProps = { ...this.props, value: el, depth: newDepth, dataPath };
                return React.createElement("li", { key: `${el}-${index}`, className: "tsjt_li", "data-attrib": helper_1.pathBuild(dataPath), style: highlighted ? { backgroundColor: highlighted.color } : {} },
                    React.createElement(NodeSelector_1.NodeSelector, Object.assign({}, newProps)));
            });
        }
        return (React.createElement(React.Fragment, null,
            React.createElement("span", { className: "tsjt_collapser", onClick: this.state.handleExpand }, this.state.collapsed ? React.createElement(PlusIcon_1.PlusIcon, { color: "#1a8b0b" }) : React.createElement(MinusIcon_1.MinusIcon, { color: "#F00" })),
            React.createElement(helper_1.OpenBracket, { symbol: '[', depth: newDepth }),
            content ? React.createElement("ul", { className: "tsjt_Array" }, content) : React.createElement("span", { onClick: this.state.handleExpand, className: "tsjt_collapser_small" }, "\u2026"),
            React.createElement(helper_1.CloseBracket, { symbol: ']', depth: newDepth })));
    }
}
exports.ArrayNode = ArrayNode;
;
exports.default = ContextWrapped_1.withContext(ArrayNode);
