"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const NodeSelector_1 = require("./NodeSelector");
const PlusIcon_1 = require("./icons/PlusIcon");
const MinusIcon_1 = require("./icons/MinusIcon");
const ContextWrapped_1 = require("./ContextWrapped");
const helper_1 = require("./helper");
const util_1 = require("util");
;
class ObjectNode extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            collapsed: props.depth > props.minLevel,
            userOverrideCollapse: false,
            handleExpand: this.handleExpand.bind(this)
        };
    }
    static getDerivedStateFromProps(nextProps, prevState) {
        const newState = {};
        if (nextProps.expandedItems.includes(helper_1.pathBuild(nextProps.dataPath)) && prevState.userOverrideCollapse === false) {
            newState.collapsed = false;
        }
        if (nextProps.highlightedItems.includes(helper_1.pathBuild(nextProps.dataPath))) {
            newState.highlighted = true;
        }
        return Object.keys(newState) ? newState : null;
    }
    handleExpand() {
        this.setState({ collapsed: !this.state.collapsed, userOverrideCollapse: true });
    }
    render() {
        const { items, depth, minLevel, highlightedItems } = this.props;
        let content;
        if (!this.state.collapsed) {
            content = Object.keys(items).map((el, index) => {
                const dataPath = [...this.props.dataPath];
                const pathElement = util_1.isNumber(el) ? `[${el}]` : `['${el}']`;
                dataPath.push(pathElement);
                const attrib = helper_1.pathBuild(dataPath);
                const highlighted = highlightedItems.find(el => el.path === attrib);
                return React.createElement("li", { key: `${el}-${index}`, className: "tsjt_li", "data-attrib": attrib, style: highlighted ? { backgroundColor: highlighted.color } : {} },
                    React.createElement("span", null, `"${el}"`),
                    React.createElement("span", { className: "tsjt_spacer" }, ":"),
                    React.createElement(NodeSelector_1.NodeSelector, { value: items[el], depth: depth + 1, dataPath: dataPath, minLevel: minLevel }));
            });
        }
        return (React.createElement(React.Fragment, null,
            React.createElement("span", { className: "tsjt_collapser", onClick: this.state.handleExpand }, this.state.collapsed ? React.createElement(PlusIcon_1.PlusIcon, { color: "#1a8b0b" }) : React.createElement(MinusIcon_1.MinusIcon, { color: "#F00" })),
            React.createElement(helper_1.OpenBracket, { symbol: '{', depth: depth + 1 }),
            content ? React.createElement("ul", { className: "tsjt_Object" }, content) : React.createElement("span", { onClick: this.state.handleExpand, className: "tsjt_collapser_small" }, "\u2026"),
            React.createElement(helper_1.CloseBracket, { symbol: '}', depth: depth + 1 })));
    }
}
exports.ObjectNode = ObjectNode;
;
exports.default = ContextWrapped_1.withContext(ObjectNode);
